=======
mscales
=======

.. image:: https://img.shields.io/travis/fabianmoss/mscales.svg
        :target: https://travis-ci.org/fabianmoss/mscales

.. image:: https://img.shields.io/pypi/v/mscales.svg
        :target: https://pypi.python.org/pypi/mscales


Python package to generate and analyze musical scales.

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://fabianmoss.github.io/mscales.

Features
--------

* TODO
